@@ -39,11 +39,10 @@ enum connman_device_type {
 	CONNMAN_DEVICE_TYPE_UNKNOWN   = 0,
 	CONNMAN_DEVICE_TYPE_ETHERNET  = 1,
 	CONNMAN_DEVICE_TYPE_WIFI      = 2,
-	CONNMAN_DEVICE_TYPE_WIMAX     = 3,
-	CONNMAN_DEVICE_TYPE_BLUETOOTH = 4,
-	CONNMAN_DEVICE_TYPE_CELLULAR  = 5,
-	CONNMAN_DEVICE_TYPE_GPS       = 6,
-	CONNMAN_DEVICE_TYPE_GADGET    = 7,
+	CONNMAN_DEVICE_TYPE_BLUETOOTH = 3,
+	CONNMAN_DEVICE_TYPE_CELLULAR  = 4,
+	CONNMAN_DEVICE_TYPE_GPS       = 5,
+	CONNMAN_DEVICE_TYPE_GADGET    = 6,
 	CONNMAN_DEVICE_TYPE_VENDOR    = 10000,
 };
 
@@ -113,6 +112,7 @@ int connman_device_set_regdom(struct connman_device *device,
 						const char *alpha2);
 void connman_device_regdom_notify(struct connman_device *device,
 					int result, const char *alpha2);
+struct connman_device *connman_device_create_from_index(int index);
 
 struct connman_device_driver {
 	const char *name;
