@@ -963,7 +963,7 @@ static void create_device(struct modem_data *modem)
 	else
 		ident = g_strdup(ident);
 
-	device = connman_device_create(ident, CONNMAN_DEVICE_TYPE_CELLULAR);
+	device = connman_device_create("ofono", CONNMAN_DEVICE_TYPE_CELLULAR);
 	if (device == NULL)
 		goto out;
 
@@ -1037,8 +1037,6 @@ static void add_network(struct modem_data *modem)
 	group = get_ident(modem->context->path);
 	connman_network_set_group(modem->network, group);
 
-	connman_network_set_available(modem->network, TRUE);
-
 	connman_network_set_bool(modem->network, "Roaming",
 					modem->roaming);
 
@@ -1698,8 +1696,10 @@ static void cm_update_attached(struct modem_data *modem,
 
 	DBG("%s Attached %d", modem->path, modem->attached);
 
-	if (modem->attached == FALSE)
+	if (modem->attached == FALSE) {
+		remove_network(modem);
 		return;
+	}
 
 	if (has_interface(modem->interfaces,
 				OFONO_API_NETREG) == FALSE) {
