@@ -200,13 +200,13 @@ int __connman_resolvfile_append(int index, const char *domain, const char *serve
 int __connman_resolvfile_remove(int index, const char *domain, const char *server);
 int __connman_resolver_redo_servers(int index);
 
-void __connman_storage_migrate(void);
 GKeyFile *__connman_storage_open_global(void);
 GKeyFile *__connman_storage_load_global(void);
 int __connman_storage_save_global(GKeyFile *keyfile);
 void __connman_storage_delete_global(void);
 
 GKeyFile *__connman_storage_load_config(const char *ident);
+GKeyFile *__connman_storage_load_provider_config(const char *ident);
 
 GKeyFile *__connman_storage_open_service(const char *ident);
 int __connman_storage_save_service(GKeyFile *keyfile, const char *ident);
@@ -362,6 +362,8 @@ int __connman_ipconfig_load(struct connman_ipconfig *ipconfig,
 int __connman_ipconfig_save(struct connman_ipconfig *ipconfig,
 		GKeyFile *keyfile, const char *identifier, const char *prefix);
 gboolean __connman_ipconfig_ipv6_privacy_enabled(struct connman_ipconfig *ipconfig);
+int __connman_ipconfig_ipv6_set_privacy(struct connman_ipconfig *ipconfig,
+					const char *value);
 
 int __connman_ipconfig_set_rp_filter();
 void __connman_ipconfig_unset_rp_filter(int old_value);
@@ -601,8 +603,12 @@ int __connman_service_set_favorite_delayed(struct connman_service *service,
 					gboolean delay_ordering);
 int __connman_service_set_immutable(struct connman_service *service,
 						connman_bool_t immutable);
+int __connman_service_set_ignore(struct connman_service *service,
+						connman_bool_t ignore);
 void __connman_service_set_userconnect(struct connman_service *service,
 						connman_bool_t userconnect);
+void __connman_service_set_search_domains(struct connman_service *service,
+					char **domains);
 
 void __connman_service_set_string(struct connman_service *service,
 					const char *key, const char *value);
@@ -651,6 +657,8 @@ void __connman_service_nameserver_add_routes(struct connman_service *service,
 						const char *gw);
 void __connman_service_nameserver_del_routes(struct connman_service *service,
 					enum connman_ipconfig_type type);
+void __connman_service_set_timeservers(struct connman_service *service,
+						char **timeservers);
 int __connman_service_timeserver_append(struct connman_service *service,
 						const char *timeserver);
 int __connman_service_timeserver_remove(struct connman_service *service,
@@ -679,6 +687,9 @@ int __connman_service_set_passphrase(struct connman_service *service,
 const char *__connman_service_get_passphrase(struct connman_service *service);
 void __connman_service_set_agent_passphrase(struct connman_service *service,
 						const char *agent_passphrase);
+int __connman_service_reset_ipconfig(struct connman_service *service,
+		enum connman_ipconfig_type type, DBusMessageIter *array,
+		enum connman_service_state *new_state);
 
 void __connman_service_notify(struct connman_service *service,
 			unsigned int rx_packets, unsigned int tx_packets,
@@ -779,10 +790,24 @@ int __connman_stats_get(struct connman_service *service,
 				connman_bool_t roaming,
 				struct connman_stats_data *data);
 
+int __connman_iptables_new_chain(const char *table_name,
+					const char *chain);
+int __connman_iptables_delete_chain(const char *table_name,
+					const char *chain);
+int __connman_iptables_flush_chain(const char *table_name,
+					const char *chain);
+int __connman_iptables_change_policy(const char *table_name,
+					const char *chain,
+					const char *policy);
+int __connman_iptables_append(const char *table_name,
+			const char *chain,
+			const char *rule_spec);
+int __connman_iptables_delete(const char *table_name,
+			const char *chain,
+			const char *rule_spec);
+
 int __connman_iptables_init(void);
 void __connman_iptables_cleanup(void);
-int __connman_iptables_command(const char *format, ...)
-				__attribute__((format(printf, 1, 2)));
 int __connman_iptables_commit(const char *table_name);
 
 int __connman_dnsproxy_init(void);
