@@ -663,11 +663,11 @@ void __connman_ipconfig_newaddr(int index, int family, const char *label,
 		__connman_ippool_newaddr(index, address, prefixlen);
 
 	if (ipdevice->config_ipv4 != NULL && family == AF_INET)
-		connman_ipaddress_copy(ipdevice->config_ipv4->system,
+		connman_ipaddress_copy_address(ipdevice->config_ipv4->system,
 					ipaddress);
 
 	else if (ipdevice->config_ipv6 != NULL && family == AF_INET6)
-		connman_ipaddress_copy(ipdevice->config_ipv6->system,
+		connman_ipaddress_copy_address(ipdevice->config_ipv6->system,
 					ipaddress);
 	else
 		return;
@@ -1718,6 +1718,25 @@ static int string2privacy(const char *privacy)
 		return 0;
 }
 
+int __connman_ipconfig_ipv6_set_privacy(struct connman_ipconfig *ipconfig,
+					const char *value)
+{
+	int privacy;
+
+	if (ipconfig == NULL)
+		return -EINVAL;
+
+	DBG("ipconfig %p privacy %s", ipconfig, value);
+
+	privacy = string2privacy(value);
+
+	ipconfig->ipv6_privacy_config = privacy;
+
+	enable_ipv6(ipconfig);
+
+	return 0;
+}
+
 void __connman_ipconfig_append_ipv4(struct connman_ipconfig *ipconfig,
 							DBusMessageIter *iter)
 {
@@ -1742,10 +1761,10 @@ void __connman_ipconfig_append_ipv4(struct connman_ipconfig *ipconfig,
 		return;
 
 	case CONNMAN_IPCONFIG_METHOD_FIXED:
+	case CONNMAN_IPCONFIG_METHOD_MANUAL:
 		append_addr = ipconfig->address;
 		break;
 
-	case CONNMAN_IPCONFIG_METHOD_MANUAL:
 	case CONNMAN_IPCONFIG_METHOD_DHCP:
 		append_addr = ipconfig->system;
 		break;
@@ -1933,6 +1952,7 @@ int __connman_ipconfig_set_config(struct connman_ipconfig *ipconfig,
 		*privacy_string = NULL;
 	int prefix_length = 0, privacy = 0;
 	DBusMessageIter dict;
+	int type = -1;
 
 	DBG("ipconfig %p", ipconfig);
 
@@ -2021,7 +2041,7 @@ int __connman_ipconfig_set_config(struct connman_ipconfig *ipconfig,
 
 	case CONNMAN_IPCONFIG_METHOD_AUTO:
 		if (ipconfig->type != CONNMAN_IPCONFIG_TYPE_IPV6)
-			return -EINVAL;
+			return -EOPNOTSUPP;
 
 		ipconfig->method = method;
 		if (privacy_string != NULL)
@@ -2030,7 +2050,26 @@ int __connman_ipconfig_set_config(struct connman_ipconfig *ipconfig,
 		break;
 
 	case CONNMAN_IPCONFIG_METHOD_MANUAL:
-		if (address == NULL)
+		switch (ipconfig->type) {
+		case CONNMAN_IPCONFIG_TYPE_IPV4:
+			type = AF_INET;
+			break;
+		case CONNMAN_IPCONFIG_TYPE_IPV6:
+			type = AF_INET6;
+			break;
+		case CONNMAN_IPCONFIG_TYPE_UNKNOWN:
+			type = -1;
+			break;
+		}
+
+		if ((address != NULL && connman_inet_check_ipaddress(address)
+						!= type) ||
+				(netmask != NULL &&
+				connman_inet_check_ipaddress(netmask)
+						!= type) ||
+				(gateway != NULL &&
+				connman_inet_check_ipaddress(gateway)
+						!= type))
 			return -EINVAL;
 
 		ipconfig->method = method;
@@ -2045,7 +2084,7 @@ int __connman_ipconfig_set_config(struct connman_ipconfig *ipconfig,
 		break;
 
 	case CONNMAN_IPCONFIG_METHOD_DHCP:
-		if (ipconfig->type == CONNMAN_IPCONFIG_TYPE_IPV6)
+		if (ipconfig->type != CONNMAN_IPCONFIG_TYPE_IPV4)
 			return -EOPNOTSUPP;
 
 		ipconfig->method = method;
